==> qore-1.8.1.tar.bz2: qore-1.8.1/docs/modules/Schema/html/namespace_schema.js <==
var namespace_schema =
[
    [ "AbstractSchema", "class_schema_1_1_abstract_schema.html", "class_schema_1_1_abstract_schema" ],
    [ "AbstractVersionedSchema", "class_schema_1_1_abstract_versioned_schema.html", "class_schema_1_1_abstract_versioned_schema" ],
    [ "SchemaCallbackHelper", "class_schema_1_1_schema_callback_helper.html", "class_schema_1_1_schema_callback_helper" ],
    [ "SchemaOptionInfo", "struct_schema_1_1_schema_option_info.html", "struct_schema_1_1_schema_option_info" ],
    [ "c_blob", "namespace_schema.html#a165649825e4c532c8ef8bdd2c2a6b9e5", null ],
    [ "c_blob", "namespace_schema.html#ae4cfd4d0c225d67309d16b6f5b60c21e", null ],
    [ "c_char", "namespace_schema.html#a52736273c7ca586665dff17acd3afc46", null ],
    [ "c_char", "namespace_schema.html#ad763cb3918d3ad2b0b8419c1e3c6c7a3", null ],
    [ "c_clob", "namespace_schema.html#a8f3b97d446484e46b3071302e7ed28a3", null ],
    [ "c_clob", "namespace_schema.html#a35d9da597bef33efc6bd2ea870af8890", null ],
    [ "c_date", "namespace_schema.html#a9035aade71090c7554aaac0a735d9844", null ],
    [ "c_date", "namespace_schema.html#a3cb8a94b74947c401fc61042889adfd0", null ],
    [ "c_int", "namespace_schema.html#aa30b4980211515bc12a14bf89970c27e", null ],
    [ "c_int", "namespace_schema.html#a89f6657fb47018dda1a767a17e434f16", null ],
    [ "c_number", "namespace_schema.html#a592cdc29516053fe0f859b81bc7dc7ac", null ],
    [ "c_number", "namespace_schema.html#a178481b69433b51bd2a69a97d01cb6fd", null ],
    [ "c_number", "namespace_schema.html#a8babcb15e6eaddb1f7650e04131b88fd", null ],
    [ "c_number", "namespace_schema.html#a0a97a85fc74910865f1388207dadcb08", null ],
    [ "c_timestamp", "namespace_schema.html#a9312e6de83b68783fd473cb95e9230f7", null ],
    [ "c_timestamp", "namespace_schema.html#ae44c6d913870d30b01398a6761b407e0", null ],
    [ "c_varchar", "namespace_schema.html#aabde003f5c3a42b01cd0d99108de8c63", null ],
    [ "c_varchar", "namespace_schema.html#aaefe7cdb0c1eed74a37a6f679dce33b7", null ],
    [ "C_NOT_NULL", "namespace_schema.html#af61cb4a2e598a8e651731f199e82d87d", null ],
    [ "C_NULL", "namespace_schema.html#af31d7ef16da53c7309e66d9b63a9aa99", null ]
];

==> qore-1.19.2.tar.bz2: qore-1.19.2/docs/modules/Schema/html/namespace_schema.js <==
var namespace_schema =
[
    [ "AbstractSchema", "class_schema_1_1_abstract_schema.html", "class_schema_1_1_abstract_schema" ],
    [ "AbstractVersionedSchema", "class_schema_1_1_abstract_versioned_schema.html", "class_schema_1_1_abstract_versioned_schema" ],
    [ "SchemaAlignmentInfo", "struct_schema_1_1_schema_alignment_info.html", "struct_schema_1_1_schema_alignment_info" ],
    [ "SchemaCallbackHelper", "class_schema_1_1_schema_callback_helper.html", "class_schema_1_1_schema_callback_helper" ],
    [ "SchemaOptionInfo", "struct_schema_1_1_schema_option_info.html", "struct_schema_1_1_schema_option_info" ],
    [ "c_blob", "namespace_schema.html#a165649825e4c532c8ef8bdd2c2a6b9e5", null ],
    [ "c_blob", "namespace_schema.html#ae4cfd4d0c225d67309d16b6f5b60c21e", null ],
    [ "c_char", "namespace_schema.html#a52736273c7ca586665dff17acd3afc46", null ],
    [ "c_char", "namespace_schema.html#ad763cb3918d3ad2b0b8419c1e3c6c7a3", null ],
    [ "c_clob", "namespace_schema.html#a8f3b97d446484e46b3071302e7ed28a3", null ],
    [ "c_clob", "namespace_schema.html#a35d9da597bef33efc6bd2ea870af8890", null ],
    [ "c_date", "namespace_schema.html#a9035aade71090c7554aaac0a735d9844", null ],
    [ "c_date", "namespace_schema.html#a3cb8a94b74947c401fc61042889adfd0", null ],
    [ "c_int", "namespace_schema.html#aa30b4980211515bc12a14bf89970c27e", null ],
    [ "c_int", "namespace_schema.html#a89f6657fb47018dda1a767a17e434f16", null ],
    [ "c_number", "namespace_schema.html#a592cdc29516053fe0f859b81bc7dc7ac", null ],
    [ "c_number", "namespace_schema.html#a178481b69433b51bd2a69a97d01cb6fd", null ],
    [ "c_number", "namespace_schema.html#a8babcb15e6eaddb1f7650e04131b88fd", null ],
    [ "c_number", "namespace_schema.html#a0a97a85fc74910865f1388207dadcb08", null ],
    [ "c_timestamp", "namespace_schema.html#a9312e6de83b68783fd473cb95e9230f7", null ],
    [ "c_timestamp", "namespace_schema.html#ae44c6d913870d30b01398a6761b407e0", null ],
    [ "c_varchar", "namespace_schema.html#aabde003f5c3a42b01cd0d99108de8c63", null ],
    [ "c_varchar", "namespace_schema.html#aaefe7cdb0c1eed74a37a6f679dce33b7", null ],
    [ "C_NOT_NULL", "namespace_schema.html#af61cb4a2e598a8e651731f199e82d87d", null ],
    [ "C_NULL", "namespace_schema.html#af31d7ef16da53c7309e66d9b63a9aa99", null ]
];
